Module block_hash

Utilities related to block hash part of the fuzzy hash.

See also: “Block Hashes” section of FuzzyHashData

Structs

IndexWindows
Numeric windows of a block hash, each value representing unique value corresponding a substring of length MIN_LCS_FOR_COMPARISON and the block size.
NumericWindows
Numeric windows of a block hash, each value representing unique value corresponding a substring of length MIN_LCS_FOR_COMPARISON.

Constants

ALPHABET_SIZE
The number of alphabets used in the block hash part of a fuzzy hash.
FULL_SIZE
The maximum size of the block hash.
HALF_SIZE
The half (truncated) size of the block hash.
MAX_SEQUENCE_SIZE
The maximum size of the sequence so that the same character can be repeated in a normalized block hash.
MIN_LCS_FOR_COMPARISON
The minimum length of the common substring to compute edit distance between two block hashes.