from_log_unchecked

Function from_log_unchecked 

pub unsafe fn from_log_unchecked(log_block_size: u8) -> u32
Available on crate feature unchecked only.
Converts base-2 logarithm form of the block size to the actual one without checking validity of the block size.

Safety

log_block_size must be valid.

See also: “Block Size” section of FuzzyHashData