Function log_from_valid_unchecked

pub unsafe fn log_from_valid_unchecked(block_size: u32) -> u8
Available on crate feature unchecked only.
Computes the base-2 logarithm form of a valid block size but do not check whether the block size is valid.

This is the same as computing n for a valid block size which can be represented as (MIN * 2n) (0 <= n).

Safety

If block_size is not valid, the result will be unpredictable.