A module containing utilities for an element of block hash position array.
Functions
- Checks whether a given position array entry has a sequence of the given length (or longer).
- The generic variant of
has_sequences().
A module containing utilities for an element of block hash position array.
has_sequences().