Utilities related to block hash part of the fuzzy hash.
See also: “Block Hashes” section of FuzzyHashData
Structs
- Index
Windows - Numeric windows of a block hash, each value representing unique value
corresponding a substring of length
MIN_LCS_FOR_COMPARISONand the block size. - Numeric
Windows - Numeric windows of a block hash, each value representing unique value
corresponding a substring of length
MIN_LCS_FOR_COMPARISON.
Constants
- ALPHABET_
SIZE - The number of alphabets used in the block hash part of a fuzzy hash.
- FULL_
SIZE - The maximum size of the block hash.
- HALF_
SIZE - The half (truncated) size of the block hash.
- MAX_
SEQUENCE_ SIZE - The maximum size of the sequence so that the same character can be repeated in a normalized block hash.
- MIN_
LCS_ FOR_ COMPARISON - The minimum length of the common substring to compute edit distance between two block hashes.