Module ssdeep::block_hash
source · Expand description
Utilities related to block hash part of the fuzzy hash.
See also: “Block Hashes” section of FuzzyHashData
Structs
- Numeric windows of a block hash, each value representing unique value corresponding a substring of length
MIN_LCS_FOR_COMPARISON.
Constants
- The number of alphabets used in the block hash part of a fuzzy hash.
- The maximum size of the block hash.
- The half (truncated) size of the block hash.
- The maximum size of the sequence so that the same character can be repeated in a normalized block hash.
- The minimum length of the common substring to compute edit distance between two block hashes.