Utility related to block size part of the fuzzy hash.
See also: “Block Size” section of FuzzyHashData
Constants
Functions
- cmp
- Compares two base-2 logarithm forms of the block size values for ordering.
- compare_
sizes - Compare two base-2 logarithm forms of the block size values to determine the relation between two block sizes.
- from_
log - Converts base-2 logarithm form of the block size to the actual one.
- from_
log_ ⚠unchecked unchecked - Converts base-2 logarithm form of the block size to the actual one without checking validity of the block size.
- is_
log_ valid - Checks whether base-2 logarithm form of the block size is valid.
- is_near
- Checks whether two base-2 logarithm forms of the block size values form a near relation (one of the three near cases).
- is_
near_ eq - Checks whether two base-2 logarithm forms of the block size values
form a
BlockSizeRelation::NearEqrelation. - is_
near_ gt - Checks whether two base-2 logarithm forms of the block size values
form a
BlockSizeRelation::NearGtrelation. - is_
near_ lt - Checks whether two base-2 logarithm forms of the block size values
form a
BlockSizeRelation::NearLtrelation. - is_
valid - Checks whether a given block size is valid.
- log_
from_ valid - Computes the base-2 logarithm form of a valid block size.
- log_
from_ ⚠valid_ unchecked unchecked - Computes the base-2 logarithm form of a valid block size but do not check whether the block size is valid.