Function ssdeep::block_size::log_from_valid

source ·
pub fn log_from_valid(block_size: u32) -> u8
Computes the base-2 logarithm form of a valid block size.

This is the same as computing n for a valid block size which can be represented as (MIN * 2n) (0 <= n).

Usage Constraints

  • block_size must be valid.